Testing QuickFIX

The development of QuickFIX has been driven by a suite of functional acceptance tests and unit tests.

# Windows

## Unit Tests

From the test directory:

    runut release [port]

The port is used to test socket functionality. If you built QuickFIX with one of its supporting databases, you will need to update cfg/ut.cfg to reflect your database settings.

## Acceptance Tests

From the test directory:

    runat release [port]

    runat_threaded release [port]

The port is used to listen for connections on a socket server.

# Linux / Solaris / FreeBSD / Mac OS X

## Unit Tests

From the test directory:

    ./runut.sh [port]

The port is used to test socket functionality. If you built QuickFIX with one of its supporting databases, you will need to update cfg/ut.cfg to reflect your database settings.

## Acceptance Tests

From the test directory:

    ./runat.sh [port]

    ./runat_threaded.sh [port]

The port is used to listen for connections on a socket server.